changeset 738:4010d1af2727 draft

Fixed names of selected tests.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Thu, 09 Jul 2015 09:37:23 +0200
parents 3fb7acf2856f
children 67d29ae6cd1b
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 80 insertions(+), 75 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Wed Jul 08 12:00:23 2015 +0200
+++ b/ChangeLog	Thu Jul 09 09:37:23 2015 +0200
@@ -1,4 +1,9 @@
-2015-07-07  Pavel Tisnovsky  <ptisnovs@redhat.com>
+2015-07-09  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Fixed names of selected tests.
+
+2015-07-08  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
 	Another sync.
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Jul 08 12:00:23 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Thu Jul 09 09:37:23 2015 +0200
@@ -12016,7 +12016,7 @@
     }
 
     /**
      * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -12025,13 +12025,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedBackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -12040,13 +12040,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedBackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -12055,13 +12055,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -12070,13 +12070,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -12085,13 +12085,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -12100,13 +12100,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -12115,13 +12115,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -12130,13 +12130,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -12145,13 +12145,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -12160,13 +12160,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -12175,9 +12175,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.black);
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.black);
     }
 
     /**
@@ -12016,7 +12016,7 @@
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.yellow.
      *